==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/sk_SK.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Nenašiel sa žiadny kalendár.",
"No events found." => "Nenašla sa žiadna udalosť.",
"Wrong calendar" => "Zlý kalendár",
"events has been saved in the new calendar" => "udalosti boli zapísané do nového kalendára",
"Import failed" => "Import zlyhal",
"events has been saved in your calendar" => "udalosti boli zapísané do kalendára",
"New Timezone:" => "Nová časová zóna:",
"Timezone changed" => "Časové pásmo zmenené",
"Invalid request" => "Neplatná požiadavka",
"Calendar" => "Kalendár",
"Deletion failed" => "Mazanie zlyhalo",
"user" => "užívateľ",
"group" => "skupina",
"Editable" => "Upravovateľné",
"Shareable" => "Zdieľateľný",
"Deletable" => "Zmazateľný",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM rrrr",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '&#8212;' d.[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, rrrr",
"Birthday" => "Narodeniny",
"Business" => "Podnikanie",
"Call" => "Hovor",
"Clients" => "Klienti",
"Deliverer" => "Doručovateľ",
"Holidays" => "Prázdniny",
"Ideas" => "Nápady",
"Journey" => "Cesta",
"Jubilee" => "Jubileá",
"Meeting" => "Stretnutia",
"Other" => "Ostatné",
"Personal" => "Osobné",
"Projects" => "Projekty",
"Questions" => "Otázky",
"Work" => "Práca",
"by" => "od",
"unnamed" => "nepomenovaný",
"You do not have the permissions to update this calendar." => "Nemáte oprávnenie pre vykonanie zmien v tomto kalendári.",
"You do not have the permissions to delete this calendar." => "Nemáte oprávnenie pre zmazanie kalendára.",
"You do not have the permissions to add to this calendar." => "Nemáte oprávnenie pre pridanie do tohto kalendára.",
"New Calendar" => "Nový kalendár",
"You do not have the permissions to add events to this calendar." => "Nemáte oprávnenie pre pridanie udalostí do tohto kalendára.",
"You do not have the permissions to edit this event." => "Nemáte oprávnenie pre úpravu tejto udalosti.",
"You do not have the permissions to delete this event." => "Nemáte oprávnenie pre zmazanie tejto udalosti.",
"Does not repeat" => "Neopakovať",
"Daily" => "Denne",
"Weekly" => "Týždenne",
"Every Weekday" => "Každý deň v týždni",
"Bi-Weekly" => "Každý druhý týždeň",
"Monthly" => "Mesačne",
"Yearly" => "Ročne",
"never" => "nikdy",
"by occurrences" => "podľa výskytu",
"by date" => "podľa dátumu",
"by monthday" => "podľa dňa v mesiaci",
"by weekday" => "podľa dňa v týždni",
"Monday" => "Pondelok",
"Tuesday" => "Utorok",
"Wednesday" => "Streda",
"Thursday" => "Štvrtok",
"Friday" => "Piatok",
"Saturday" => "Sobota",
"Sunday" => "Nedeľa",
"events week of month" => "týždenné udalosti v mesiaci",
"first" => "prvý",
"second" => "druhý",
"third" => "tretí",
"fourth" => "štvrtý",
"fifth" => "piaty",
"last" => "posledný",
"January" => "Január",
"February" => "Február",
"March" => "Marec",
"April" => "Apríl",
"May" => "Máj",
"June" => "Jún",
"July" => "Júl",
"August" => "August",
"September" => "September",
"October" => "Október",
"November" => "November",
"December" => "December",
"by events date" => "podľa dátumu udalosti",
"by yearday(s)" => "po dňoch",
"by weeknumber(s)" => "podľa čísel týždňov",
"by day and month" => "podľa dňa a mesiaca",
"Date" => "Dátum",
"Cal." => "Kal.",
"Sun." => "Ned.",
"Mon." => "Pon.",
"Tue." => "Uto.",
"Wed." => "Str.",
"Thu." => "Štv.",
"Fri." => "Pia.",
"Sat." => "Sob.",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Máj.",
"Jun." => "Jún.",
"Jul." => "Júl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Celý deň",
"Missing fields" => "Nevyplnené položky",
"Title" => "Nadpis",
"From Date" => "Od dátumu",
"From Time" => "Od času",
"To Date" => "Do dátumu",
"To Time" => "Do času",
"The event ends before it starts" => "Udalosť končí ešte pred tým než začne",
"There was a database fail" => "Nastala chyba databázy",
"Week" => "Týždeň",
"Month" => "Mesiac",
"List" => "Zoznam",
"Today" => "Dnes",
"Calendars" => "Kalendáre",
"Settings" => "Nastavenia",
"Your calendars" => "Vaše kalendáre",
"CalDav Link" => "CalDav odkaz",
"Share Calendar" => "Zdielať kalendár",
"Download" => "Stiahnuť",
"Edit" => "Upraviť",
"Delete" => "Odstrániť",
"shared with you by" => "zdielané s vami používateľom",
"New calendar" => "Nový kalendár",
"Edit calendar" => "Upraviť kalendár",
"Displayname" => "Zobrazené meno",
"Active" => "Aktívne",
"Calendar color" => "Farba kalendáru",
"Save" => "Uložiť",
"Submit" => "Odoslať",
"Cancel" => "Zrušiť",
"Edit an event" => "Upraviť udalosť",
"Export" => "Exportovať",
"Eventinfo" => "Informácie o udalosti",
"Repeating" => "Opakovanie",
"Alarm" => "Alarm",
"Attendees" => "Účastníci",
"Share" => "Zdielať",
"Title of the Event" => "Nadpis udalosti",
"Category" => "Kategória",
"Separate categories with commas" => "Kategórie oddelené čiarkami",
"Edit categories" => "Úprava kategórií",
"All Day Event" => "Celodenná udalosť",
"From" => "Od",
"To" => "Do",
"Advanced options" => "Pokročilé možnosti",
"Location" => "Poloha",
"Location of the Event" => "Poloha udalosti",
"Description" => "Popis",
"Description of the Event" => "Popis udalosti",
"Repeat" => "Opakovať",
"Advanced" => "Pokročilé",
"Select weekdays" => "Do času",
"Select days" => "Vybrať dni",
"and the events day of year." => "a denné udalosti v roku.",
"and the events day of month." => "a denné udalosti v mesiaci.",
"Select months" => "Vybrať mesiace",
"Select weeks" => "Vybrať týždne",
"and the events week of year." => "a týždenné udalosti v roku.",
"Interval" => "Interval",
"End" => "Koniec",
"occurrences" => "výskyty",
"create a new calendar" => "vytvoriť nový kalendár",
"Import a calendar file" => "Importovať súbor kalendára",
"Please choose a calendar" => "Vybrať si kalendár",
"Name of new calendar" => "Meno nového kalendára",
"Take an available name!" => "Vybrať existujúce meno",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendár s rovnakým názvom už existuje. Pokračovaním kalendáre spojíte.",
"Import" => "Importovať",
"Close Dialog" => "Zatvoriť dialóg",
"Create a new event" => "Vytvoriť udalosť",
"Share with:" => "Zdieľať s:",
"Shared with" => "Zdieľaný s:",
"Unshare" => "Nezdieľať",
"Nobody" => "Nikto",
"Shared via calendar" => "Zdieľané cez kalendár",
"View an event" => "Zobraziť udalosť",
"No categories selected" => "Žiadne vybraté kategórie",
"of" => "z",
"at" => "v",
"General" => "Všeobecné",
"Timezone" => "Časová zóna",
"Update timezone automatically" => "Automaticky aktualizovať časovú zónu",
"Time format" => "Formát času",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Týždeň začína v ",
"URLs" => "Odkazy URL",
"more info" => "viac informácií",
"Primary address (Kontact et al)" => "Primárna adresa",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Odkazy na iCalendar (iba na čítanie)"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/sk_SK.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "V pamäti nie sú úplne uložené všetky kalendáre",
"Everything seems to be completely cached" => "Zdá sa, že je všetko úplne uložené v pamäti",
"No calendars found." => "Nenašiel sa žiadny kalendár.",
"No events found." => "Nenašla sa žiadna udalosť.",
"Wrong calendar" => "Zlý kalendár",
"You do not have the permissions to edit this event." => "Nemáte oprávnenie pre úpravu tejto udalosti.",
"The file contained either no events or all events are already saved in your calendar." => "Súbor neobsahoval žiadne udalosti, alebo už sú všetky udalosti vo Vašom kalendári.",
"events has been saved in the new calendar" => "udalosti boli zapísané do nového kalendára",
"Import failed" => "Import zlyhal",
"events has been saved in your calendar" => "udalosti boli zapísané do kalendára",
"New Timezone:" => "Nová časová zóna:",
"Timezone changed" => "Časové pásmo zmenené",
"Invalid request" => "Neplatná požiadavka",
"Calendar" => "Kalendár",
"Deletion failed" => "Odstránenie zlyhalo",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"user" => "používateľ",
"group" => "skupina",
"Editable" => "Upravovateľné",
"Shareable" => "Zdieľateľný",
"Deletable" => "Zmazateľný",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '&#8212;' d.[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Nedeľa",
"Monday" => "Pondelok",
"Tuesday" => "Utorok",
"Wednesday" => "Streda",
"Thursday" => "Štvrtok",
"Friday" => "Piatok",
"Saturday" => "Sobota",
"Sun." => "Ned.",
"Mon." => "Pon.",
"Tue." => "Uto.",
"Wed." => "Str.",
"Thu." => "Štv.",
"Fri." => "Pia.",
"Sat." => "Sob.",
"January" => "Január",
"February" => "Február",
"March" => "Marec",
"April" => "Apríl",
"May" => "Máj",
"June" => "Jún",
"July" => "Júl",
"August" => "August",
"September" => "September",
"October" => "Október",
"November" => "November",
"December" => "December",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Máj.",
"Jun." => "Jún.",
"Jul." => "Júl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Celý deň",
"New Calendar" => "Nový kalendár",
"Missing or invalid fields" => "Chýbajúce alebo neplatné polia",
"Title" => "Nadpis",
"From Date" => "Od dátumu",
"From Time" => "Od času",
"To Date" => "Do dátumu",
"To Time" => "Do času",
"The event ends before it starts" => "Udalosť končí ešte pred tým než začne",
"There was a database fail" => "Nastala chyba databázy",
"Birthday" => "Narodeniny",
"Business" => "Podnikanie",
"Call" => "Hovor",
"Clients" => "Klienti",
"Deliverer" => "Doručovateľ",
"Holidays" => "Prázdniny",
"Ideas" => "Nápady",
"Journey" => "Cesta",
"Jubilee" => "Jubileá",
"Meeting" => "Stretnutia",
"Other" => "Ostatné",
"Personal" => "Osobné",
"Projects" => "Projekty",
"Questions" => "Otázky",
"Work" => "Práca",
"by" => "od",
"unnamed" => "nepomenovaný",
"You do not have the permissions to update this calendar." => "Nemáte oprávnenie pre vykonanie zmien v tomto kalendári.",
"You do not have the permissions to delete this calendar." => "Nemáte oprávnenie pre odstránenie kalendára.",
"You do not have the permissions to add to this calendar." => "Nemáte oprávnenie pre pridanie do tohto kalendára.",
"You do not have the permissions to add events to this calendar." => "Nemáte oprávnenie pre pridanie udalostí do tohto kalendára.",
"You do not have the permissions to delete this event." => "Nemáte oprávnenie pre odstránenie tejto udalosti.",
"Busy" => "Zaneprázdený",
"Public" => "Verejný",
"Private" => "Súkromný",
"Confidential" => "Tajný",
"Does not repeat" => "Neopakovať",
"Daily" => "Denne",
"Weekly" => "Týždenne",
"Every Weekday" => "Každý deň v týždni",
"Bi-Weekly" => "Každý druhý týždeň",
"Monthly" => "Mesačne",
"Yearly" => "Ročne",
"never" => "nikdy",
"by occurrences" => "podľa výskytu",
"by date" => "podľa dátumu",
"by monthday" => "podľa dňa v mesiaci",
"by weekday" => "podľa dňa v týždni",
"events week of month" => "týždenné udalosti v mesiaci",
"first" => "prvý",
"second" => "druhý",
"third" => "tretí",
"fourth" => "štvrtý",
"fifth" => "piaty",
"last" => "posledný",
"by events date" => "podľa dátumu udalosti",
"by yearday(s)" => "po dňoch",
"by weeknumber(s)" => "podľa čísel týždňov",
"by day and month" => "podľa dňa a mesiaca",
"Date" => "Dátum",
"Cal." => "Kal.",
"Week" => "Týždeň",
"Month" => "Mesiac",
"List" => "Zoznam",
"Today" => "Dnes",
"Settings" => "Nastavenia",
"Your calendars" => "Vaše kalendáre",
"CalDav Link" => "CalDav odkaz",
"Share Calendar" => "Zdielať kalendár",
"Download" => "Stiahnuť",
"Edit" => "Upraviť",
"Delete" => "Odstrániť",
"New calendar" => "Nový kalendár",
"Edit calendar" => "Upraviť kalendár",
"Displayname" => "Zobrazené meno",
"Active" => "Aktívne",
"Calendar color" => "Farba kalendára",
"Save" => "Uložiť",
"Submit" => "Odoslať",
"Cancel" => "Zrušiť",
"Edit an event" => "Upraviť udalosť",
"Export" => "Exportovať",
"Eventinfo" => "Informácie o udalosti",
"Repeating" => "Opakovanie",
"Alarm" => "Alarm",
"Attendees" => "Účastníci",
"Share" => "Zdielať",
"Title of the Event" => "Nadpis udalosti",
"Category" => "Kategória",
"Separate categories with commas" => "Kategórie oddelené čiarkami",
"Edit categories" => "Úprava kategórií",
"Access Class" => "Prístupová trieda",
"All Day Event" => "Celodenná udalosť",
"From" => "Od",
"To" => "Do",
"Advanced options" => "Pokročilé možnosti",
"Location" => "Poloha",
"Location of the Event" => "Poloha udalosti",
"Description" => "Popis",
"Description of the Event" => "Popis udalosti",
"Repeat" => "Opakovať",
"Advanced" => "Pokročilé",
"Select weekdays" => "Do času",
"Select days" => "Vybrať dni",
"and the events day of year." => "a denné udalosti v roku.",
"and the events day of month." => "a denné udalosti v mesiaci.",
"Select months" => "Vybrať mesiace",
"Select weeks" => "Vybrať týždne",
"and the events week of year." => "a týždenné udalosti v roku.",
"Interval" => "Interval",
"End" => "Koniec",
"occurrences" => "výskyty",
"create a new calendar" => "vytvoriť nový kalendár",
"Import a calendar file" => "Importovať súbor kalendára",
"Please choose a calendar" => "Vybrať si kalendár",
"Name of new calendar" => "Meno nového kalendára",
"Take an available name!" => "Vybrať existujúce meno",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendár s rovnakým názvom už existuje. Pokračovaním kalendáre spojíte.",
"Remove all events from the selected calendar" => "Odstrániť všetky udalosti z vybraného kalendára",
"Import" => "Importovať",
"Close Dialog" => "Zatvoriť dialóg",
"Create a new event" => "Vytvoriť udalosť",
"Share with:" => "Zdieľať s:",
"Shared with" => "Zdieľaný s:",
"Unshare" => "Nezdieľať",
"Nobody" => "Nikto",
"Shared via calendar" => "Zdieľané cez kalendár",
"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "POZNÁMKA: Činnosti na udalostiach zdieľaných cez kalendár budú mať vplyv na zdieľanie celého kalendára.",
"View an event" => "Zobraziť udalosť",
"No categories selected" => "Žiadne vybraté kategórie",
"of" => "z",
"at" => "v",
"General" => "Všeobecné",
"Timezone" => "Časová zóna",
"Update timezone automatically" => "Automaticky aktualizovať časovú zónu",
"Time format" => "Formát času",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Týždeň začína v ",
"Cache" => "Vyrovnávacia pamäť",
"Clear cache for repeating events" => "Vymazať vyrovnávaciu pamäť pre opakujúce sa udalosti",
"URLs" => "Odkazy URL",
"Calendar CalDAV syncing addresses" => "Kalendár CalDAV synchronizuje adresy",
"more info" => "viac informácií",
"Primary address (Kontact et al)" => "Primárna adresa",
"iOS/OS X" => "iOS/OS X",
"Read only iCalendar link(s)" => "Odkazy na iCalendar (iba na čítanie)"
);
